@@ -105,9 +105,7 @@
 /* #undef HAVE_IPP */
 /* #undef HAVE_IPP_ICV */
 /* #undef HAVE_IPP_IW */
-
-/* Intel IPP Async */
-/* #undef HAVE_IPP_A */
+/* #undef HAVE_IPP_IW_LL */
 
 /* JPEG-2000 codec */
 #define HAVE_JASPER
@@ -244,5 +242,7 @@
 /* OpenCV trace utilities */
 #define OPENCV_TRACE
 
+/* Library QR-code decoding */
+#define HAVE_QUIRC
 
 #endif // OPENCV_CVCONFIG_H_INCLUDED
